# humancenteredTSA
human centered TimeSeries Analysis

## Project Structure
- hctsa: core folders and files
- - descriptive timeseries analysis
- - preparation of timeseries data
- - pattern recognition metrics
- - visualizations and explainability

## Dependencies
- pandas
